==> haskell-dependent-map-0.4.0.0-247-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-JOGG5YNJ15u2ZmZbmfLdTI
key:                  dependent-map-0.4.0.0-JOGG5YNJ15u2ZmZbmfLdTI
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  cb7d4666d76f0cb156de1bae00dbc4ac
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-JOGG5YNJ15u2ZmZbmfLdTI
depends:
    base-4.16.4.0 constraints-extras-0.4.0.1-KkjRZxA8M60uREMAyrqht
    containers-0.6.5.1 dependent-sum-0.7.2.0-DODsEySkCmL4o44uHBZRPZ

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-map-0.4.0.0-248-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-ChkxjwxtcKcAl6sp4O4g7z
key:                  dependent-map-0.4.0.0-ChkxjwxtcKcAl6sp4O4g7z
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  3b8d752a1f1fee9cbbabaf290fe1b411
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-ChkxjwxtcKcAl6sp4O4g7z
depends:
    base-4.16.4.0 constraints-extras-0.4.0.1-twjDICgYHpGjZeuhnEQlt
    containers-0.6.5.1 dependent-sum-0.7.2.0-3iWOOUgwIaC1jhhWAczqDx

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
